# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from spounge.common.v2 import common_pb2 as common_dot_v2_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15polykey/v2/auth.proto\x12\npolykey.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x16\x63ommon/v2/common.proto\"j\n\x13\x41uthenticateRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x17\n\x07\x61pi_key\x18\x02 \x01(\tR\x06\x61piKey\x12\x1d\n\ngrant_type\x18\x03 \x01(\tR\tgrantType\"\x8a\x02\n\x14\x41uthenticateResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12\x1d\n\ntoken_type\x18\x02 \x01(\tR\ttokenType\x12\x1d\n\nexpires_in\x18\x03 \x01(\x03R\texpiresIn\x12 \n\x0bpermissions\x18\x04 \x03(\tR\x0bpermissions\x12\x37\n\tissued_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08issuedAt\x12\x36\n\x0b\x63lient_tier\x18\x06 \x01(\x0e\x32\x15.common.v2.ClientTierR\nclientTier\":\n\x13RefreshTokenRequest\x12#\n\rrefresh_token\x18\x01 \x01(\tR\x0crefreshToken\"\xb0\x01\n\x14RefreshTokenResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12\x1d\n\ntoken_type\x18\x02 \x01(\tR\ttokenType\x12\x1d\n\nexpires_in\x18\x03 \x01(\x03R\texpiresIn\x12\x37\n\tissued_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08issuedAt\"T\n\x12RevokeTokenRequest\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12\x1b\n\tclient_id\x18\x02 \x01(\tR\x08\x63lientId\"j\n\x13RevokeTokenResponse\x12\x18\n\x07revoked\x18\x01 \x01(\x08R\x07revoked\x12\x39\n\nrevoked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trevokedAt\"\xbf\x02\n\nClientInfo\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x1f\n\x0b\x63lient_name\x18\x02 \x01(\tR\nclientName\x12 \n\x0bpermissions\x18\x03 \x03(\tR\x0bpermissions\x12 \n\x0b\x65nvironment\x18\x04 \x01(\tR\x0b\x65nvironment\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12<\n\x0clast_used_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nlastUsedAt\x12\x36\n\x0b\x63lient_tier\x18\x07 \x01(\x0e\x32\x15.common.v2.ClientTierR\nclientTierB\xa5\x01\n\x0e\x63om.polykey.v2B\tAuthProtoP\x01Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\tAuthProtoP\001Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_AUTHENTICATEREQUEST']._serialized_start=94
  _globals['_AUTHENTICATEREQUEST']._serialized_end=200
  _globals['_AUTHENTICATERESPONSE']._serialized_start=203
  _globals['_AUTHENTICATERESPONSE']._serialized_end=469
  _globals['_REFRESHTOKENREQUEST']._serialized_start=471
  _globals['_REFRESHTOKENREQUEST']._serialized_end=529
  _globals['_REFRESHTOKENRESPONSE']._serialized_start=532
  _globals['_REFRESHTOKENRESPONSE']._serialized_end=708
  _globals['_REVOKETOKENREQUEST']._serialized_start=710
  _globals['_REVOKETOKENREQUEST']._serialized_end=794
  _globals['_REVOKETOKENRESPONSE']._serialized_start=796
  _globals['_REVOKETOKENRESPONSE']._serialized_end=902
  _globals['_CLIENTINFO']._serialized_start=905
  _globals['_CLIENTINFO']._serialized_end=1224
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/polykey_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "polykey/v2/polykey_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n polykey/v2/polykey_service.proto\x12\npolykey.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto"\xcb\x01\n\x12\x45xecuteToolRequest\x12\x1b\n\ttool_name\x18\x01 \x01(\tR\x08toolName\x12\x37\n\nparameters\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\nparameters\x12 \n\tsecret_id\x18\x03 \x01(\tH\x00R\x08secretId\x88\x01\x01\x12/\n\x08metadata\x18\x04 \x01(\x0b\x32\x13.common.v2.MetadataR\x08metadataB\x0c\n\n_secret_id"\xe5\x01\n\x13\x45xecuteToolResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12%\n\rstring_output\x18\x02 \x01(\tH\x00R\x0cstringOutput\x12>\n\rstruct_output\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x0cstructOutput\x12\x32\n\x0b\x66ile_output\x18\x04 \x01(\x0b\x32\x0f.common.v2.FileH\x00R\nfileOutputB\x08\n\x06output2`\n\x0ePolykeyService\x12N\n\x0b\x45xecuteTool\x12\x1e.polykey.v2.ExecuteToolRequest\x1a\x1f.polykey.v2.ExecuteToolResponseB\xb0\x01\n\x0e\x63om.polykey.v2B\x13PolykeyServiceProtoP\x01Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "polykey.v2.polykey_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\016com.polykey.v2B\023PolykeyServiceProtoP\001Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2"
    _globals["_EXECUTETOOLREQUEST"]._serialized_start = 103
    _globals["_EXECUTETOOLREQUEST"]._serialized_end = 306
    _globals["_EXECUTETOOLRESPONSE"]._serialized_start = 309
    _globals["_EXECUTETOOLRESPONSE"]._serialized_end = 538
    _globals["_POLYKEYSERVICE"]._serialized_start = 540
    _globals["_POLYKEYSERVICE"]._serialized_end = 636
# @@protoc_insertion_point(module_scope)



# Auto-generated __init__.py
from . import decl_pb2, decl_pb2_grpc, eval_pb2, eval_pb2_grpc, expr_pb2, expr_pb2_grpc, source_pb2, source_pb2_grpc, value_pb2, value_pb2_grpc

__all__ = ["decl_pb2", "decl_pb2_grpc", "eval_pb2", "eval_pb2_grpc", "expr_pb2", "expr_pb2_grpc", "source_pb2", "source_pb2_grpc", "value_pb2", "value_pb2_grpc"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user/v2/user_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "user/v2/user_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1auser/v2/user_service.proto\x12\x07user.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1biam/v2/managed_secret.proto\x1a\x12user/v2/user.proto"H\n\x16GetUserProfileResponse\x12.\n\x07profile\x18\x01 \x01(\x0b\x32\x14.user.v2.UserProfileR\x07profile"\x87\x01\n\x18UpdateUserProfileRequest\x12;\n\x0bupdate_mask\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\x12.\n\x07profile\x18\x02 \x01(\x0b\x32\x14.user.v2.UserProfileR\x07profile"K\n\x19UpdateUserProfileResponse\x12.\n\x07profile\x18\x01 \x01(\x0b\x32\x14.user.v2.UserProfileR\x07profile"\x88\x01\n\x17\x41\x64\x64ManagedSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12-\n\x04type\x18\x02 \x01(\x0e\x32\x19.iam.v2.ManagedSecretTypeR\x04type\x12*\n\x11plain_text_secret\x18\x03 \x01(\tR\x0fplainTextSecret"I\n\x18\x41\x64\x64ManagedSecretResponse\x12-\n\x06secret\x18\x01 \x01(\x0b\x32\x15.iam.v2.ManagedSecretR\x06secret"M\n\x1aListManagedSecretsResponse\x12/\n\x07secrets\x18\x01 \x03(\x0b\x32\x15.iam.v2.ManagedSecretR\x07secrets"6\n\x17GetManagedSecretRequest\x12\x1b\n\tsecret_id\x18\x01 \x01(\tR\x08secretId"I\n\x18GetManagedSecretResponse\x12-\n\x06secret\x18\x01 \x01(\x0b\x32\x15.iam.v2.ManagedSecretR\x06secret"9\n\x1a\x44\x65leteManagedSecretRequest\x12\x1b\n\tsecret_id\x18\x01 \x01(\tR\x08secretId"H\n\x1b\x44\x65leteManagedSecretResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status2\xa7\x04\n\x0bUserService\x12K\n\x0eGetUserProfile\x12\x16.google.protobuf.Empty\x1a\x1f.user.v2.GetUserProfileResponse"\x00\x12\\\n\x11UpdateUserProfile\x12!.user.v2.UpdateUserProfileRequest\x1a".user.v2.UpdateUserProfileResponse"\x00\x12Y\n\x10\x41\x64\x64ManagedSecret\x12 .user.v2.AddManagedSecretRequest\x1a!.user.v2.AddManagedSecretResponse"\x00\x12S\n\x12ListManagedSecrets\x12\x16.google.protobuf.Empty\x1a#.user.v2.ListManagedSecretsResponse"\x00\x12Y\n\x10GetManagedSecret\x12 .user.v2.GetManagedSecretRequest\x1a!.user.v2.GetManagedSecretResponse"\x00\x12\x62\n\x13\x44\x65leteManagedSecret\x12#.user.v2.DeleteManagedSecretRequest\x1a$.user.v2.DeleteManagedSecretResponse"\x00\x42\x98\x01\n\x0b\x63om.user.v2B\x10UserServiceProtoP\x01Z:github.com/spounge-ai/spounge-protos/gen/go/user/v2;userv2\xa2\x02\x03UXX\xaa\x02\x07User.V2\xca\x02\x07User\\V2\xe2\x02\x13User\\V2\\GPBMetadata\xea\x02\x08User::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "user.v2.user_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\013com.user.v2B\020UserServiceProtoP\001Z:github.com/spounge-ai/spounge-protos/gen/go/user/v2;userv2\242\002\003UXX\252\002\007User.V2\312\002\007User\\V2\342\002\023User\\V2\\GPBMetadata\352\002\010User::V2"
    _globals["_GETUSERPROFILERESPONSE"]._serialized_start = 175
    _globals["_GETUSERPROFILERESPONSE"]._serialized_end = 247
    _globals["_UPDATEUSERPROFILEREQUEST"]._serialized_start = 250
    _globals["_UPDATEUSERPROFILEREQUEST"]._serialized_end = 385
    _globals["_UPDATEUSERPROFILERESPONSE"]._serialized_start = 387
    _globals["_UPDATEUSERPROFILERESPONSE"]._serialized_end = 462
    _globals["_ADDMANAGEDSECRETREQUEST"]._serialized_start = 465
    _globals["_ADDMANAGEDSECRETREQUEST"]._serialized_end = 601
    _globals["_ADDMANAGEDSECRETRESPONSE"]._serialized_start = 603
    _globals["_ADDMANAGEDSECRETRESPONSE"]._serialized_end = 676
    _globals["_LISTMANAGEDSECRETSRESPONSE"]._serialized_start = 678
    _globals["_LISTMANAGEDSECRETSRESPONSE"]._serialized_end = 755
    _globals["_GETMANAGEDSECRETREQUEST"]._serialized_start = 757
    _globals["_GETMANAGEDSECRETREQUEST"]._serialized_end = 811
    _globals["_GETMANAGEDSECRETRESPONSE"]._serialized_start = 813
    _globals["_GETMANAGEDSECRETRESPONSE"]._serialized_end = 886
    _globals["_DELETEMANAGEDSECRETREQUEST"]._serialized_start = 888
    _globals["_DELETEMANAGEDSECRETREQUEST"]._serialized_end = 945
    _globals["_DELETEMANAGEDSECRETRESPONSE"]._serialized_start = 947
    _globals["_DELETEMANAGEDSECRETRESPONSE"]._serialized_end = 1019
    _globals["_USERSERVICE"]._serialized_start = 1022
    _globals["_USERSERVICE"]._serialized_end = 1573
# @@protoc_insertion_point(module_scope)



# Auto-generated __init__.py
from . import auth_pb2, auth_pb2_grpc, batch_operations_pb2, batch_operations_pb2_grpc, common_pb2, common_pb2_grpc, key_types_pb2, key_types_pb2_grpc, metrics_pb2, metrics_pb2_grpc, service_pb2, service_pb2_grpc, single_operations_pb2, single_operations_pb2_grpc, stream_operations_pb2, stream_operations_pb2_grpc

__all__ = ["auth_pb2", "auth_pb2_grpc", "batch_operations_pb2", "batch_operations_pb2_grpc", "common_pb2", "common_pb2_grpc", "key_types_pb2", "key_types_pb2_grpc", "metrics_pb2", "metrics_pb2_grpc", "service_pb2", "service_pb2_grpc", "single_operations_pb2", "single_operations_pb2_grpc", "stream_operations_pb2", "stream_operations_pb2_grpc"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common/v2/common.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "common/v2/common.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16\x63ommon/v2/common.proto\x12\tcommon.v2\x1a\x1cgoogle/protobuf/struct.proto"i\n\x06Status\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x31\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x07\x64\x65tails"Z\n\x04\x46ile\x12\x1b\n\tfile_name\x18\x01 \x01(\tR\x08\x66ileName\x12\x1b\n\tmime_type\x18\x02 \x01(\tR\x08mimeType\x12\x18\n\x07\x63ontent\x18\x03 \x01(\x0cR\x07\x63ontent"C\n\x10PaginationParams\x12\x12\n\x04page\x18\x01 \x01(\x05R\x04page\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize"\x85\x01\n\x10PaginationResult\x12\x12\n\x04page\x18\x01 \x01(\x05R\x04page\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1f\n\x0btotal_items\x18\x03 \x01(\x05R\ntotalItems\x12\x1f\n\x0btotal_pages\x18\x04 \x01(\x05R\ntotalPages"\x1a\n\x08\x45ntityId\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id"~\n\x08Metadata\x12\x37\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x1f.common.v2.Metadata.FieldsEntryR\x06\x66ields\x1a\x39\n\x0b\x46ieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xa1\x01\n\rcom.common.v2B\x0b\x43ommonProtoP\x01Z>github.com/spounge-ai/spounge-protos/gen/go/common/v2;commonv2\xa2\x02\x03\x43XX\xaa\x02\tCommon.V2\xca\x02\tCommon\\V2\xe2\x02\x15\x43ommon\\V2\\GPBMetadata\xea\x02\nCommon::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "common.v2.common_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\rcom.common.v2B\013CommonProtoP\001Z>github.com/spounge-ai/spounge-protos/gen/go/common/v2;commonv2\242\002\003CXX\252\002\tCommon.V2\312\002\tCommon\\V2\342\002\025Common\\V2\\GPBMetadata\352\002\nCommon::V2"
    _globals["_METADATA_FIELDSENTRY"]._loaded_options = None
    _globals["_METADATA_FIELDSENTRY"]._serialized_options = b"8\001"
    _globals["_STATUS"]._serialized_start = 67
    _globals["_STATUS"]._serialized_end = 172
    _globals["_FILE"]._serialized_start = 174
    _globals["_FILE"]._serialized_end = 264
    _globals["_PAGINATIONPARAMS"]._serialized_start = 266
    _globals["_PAGINATIONPARAMS"]._serialized_end = 333
    _globals["_PAGINATIONRESULT"]._serialized_start = 336
    _globals["_PAGINATIONRESULT"]._serialized_end = 469
    _globals["_ENTITYID"]._serialized_start = 471
    _globals["_ENTITYID"]._serialized_end = 497
    _globals["_METADATA"]._serialized_start = 499
    _globals["_METADATA"]._serialized_end = 625
    _globals["_METADATA_FIELDSENTRY"]._serialized_start = 568
    _globals["_METADATA_FIELDSENTRY"]._serialized_end = 625
# @@protoc_insertion_point(module_scope)
